/*
 * glade-gtk-activatable.h
 *
 * Copyright (C) 2010 Tristan Van Berkom.
 *
 * Author:
 *   Tristan Van Berkom <tvb@gnome.org>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef __GLADE_GTK_ACTIVATABLE_H__
#define __GLADE_GTK_ACTIVATABLE_H__

#include <gladeui/glade.h>
#include "glade-gtk.h"

G_BEGIN_DECLS

void
glade_gtk_activatable_evaluate_property_sensitivity (GObject *object,
                                                     const gchar *id,
                                                     const GValue *value);

G_END_DECLS

#endif /* __GLADE_GTK_ACTIVATABLE_H__ */
